/*
   Remote Sketch for MAX485 module 5v TLL to RS-485 converter
   
   This sample code is for interface an Arduino used for
   Serial Communications over longer distances than direct RS232/TTL,
   Supports multiple units on the same bus.
   
   Remote received data and it loops back
   Wiring Connections:
   gizDuino board          RS-485 module
     DI (Data In)            D11
     RO (Receive Out)        D10
     DE (Data Enable)        D3
     and RE (receive enable)
     VCC                     +5V
     A                       A (another RS-485)*
     B                       B *
     GND                     GND
     
     - To other unit pins 11,10,GND (Cross Over)
     - Pin 3 used for RS485 direction control
     - Pin 13 LED blinks when data is received
     
     Refernce:
     https://arduino-info.wikispaces.com/SoftwareSerialRS485Example
    
    
   Written by:
   e-Gizmo Mechatronix Central
   http://www.e-gizmo.com
   March 23, 2017
*/

#include <SoftwareSerial.h>

#define RXpin        10  //Serial Receive pin
#define TXpin        11  //Serial Transmit pin

#define TXcontrol 3   //RS485 Direction control
#define RS485Tx    HIGH
#define RS485Rx     LOW

#define LED         13

SoftwareSerial RS485(RXpin, TXpin); // RX, TX

int byteReceived;
int byteSend;

void setup()
{
  Serial.begin(9600); 
  pinMode(LED, OUTPUT);   
  pinMode(TXcontrol, OUTPUT);  
  digitalWrite(TXcontrol, RS485Rx);
  RS485.begin(4800);   // set the data rate 
}

void loop()
{
  if (RS485.available()) 
  {
    byteSend = RS485.read();
    Serial.println("e-Gizmo Mechatronix Central");
    digitalWrite(LED, HIGH);
    delay(10);              
    digitalWrite(LED, LOW);
    
    
    digitalWrite(TXcontrol, RS485Tx);    
    RS485.write(byteSend);
    delay(10);   
    digitalWrite(TXcontrol, RS485Rx);   

  }
  
}


